==> JDA-5.3.1-sources.jar: net/dv8tion/jda/api/interactions/callbacks/IModalCallback.java <==
/*
 * Copyright 2015 Austin Keener, Michael Ritter, Florian Spieß, and the JDA contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dv8tion.jda.api.interactions.callbacks;

import net.dv8tion.jda.api.interactions.Interaction;
import net.dv8tion.jda.api.interactions.modals.Modal;
import net.dv8tion.jda.api.requests.restaction.interactions.ModalCallbackAction;

import javax.annotation.CheckReturnValue;
import javax.annotation.Nonnull;

/**
 * Interactions which allow sending modals as a response.
 *
 * <p>Sending a modal using {@link #replyModal(Modal)} will automatically acknowledge this interaction.
 */
public interface IModalCallback extends Interaction
{
    /**
     * Acknowledgement of this interaction with a {@link Modal Modal}.
     *
     * <p>This will open a popup on the target user's Discord client.
     *
     * <p>Interactions can only be acknowledged once.
     *
     * <p><b>You only have 3 seconds to acknowledge an interaction!</b>
     * <br>When the acknowledgement is sent after the interaction expired, you will receive {@link net.dv8tion.jda.api.requests.ErrorResponse#UNKNOWN_INTERACTION ErrorResponse.UNKNOWN_INTERACTION}.
     *
     * @param  modal 
     *         The Modal to send
     *
     * @throws IllegalArgumentException
     *         If the provided modal is null
     *        
     * @return ModalCallbackAction
     */
    @Nonnull
    @CheckReturnValue
    ModalCallbackAction replyModal(@Nonnull Modal modal);
}

==> JDA-6.0.0-rc.5-sources.jar: net/dv8tion/jda/api/interactions/callbacks/IModalCallback.java <==
/*
 * Copyright 2015 Austin Keener, Michael Ritter, Florian Spieß, and the JDA contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dv8tion.jda.api.interactions.callbacks;

import net.dv8tion.jda.api.interactions.Interaction;
import net.dv8tion.jda.api.modals.Modal;
import net.dv8tion.jda.api.requests.restaction.interactions.ModalCallbackAction;

import javax.annotation.CheckReturnValue;
import javax.annotation.Nonnull;

/**
 * Interactions which allow sending modals as a response.
 *
 * <p>Sending a modal using {@link #replyModal(Modal)} will automatically acknowledge this interaction.
 */
public interface IModalCallback extends Interaction
{
    /**
     * Acknowledgement of this interaction with a {@link Modal Modal}.
     *
     * <p>This will open a popup on the target user's Discord client.
     *
     * <p>Interactions can only be acknowledged once.
     *
     * <p><b>You only have 3 seconds to acknowledge an interaction!</b>
     * <br>When the acknowledgement is sent after the interaction expired, you will receive {@link net.dv8tion.jda.api.requests.ErrorResponse#UNKNOWN_INTERACTION ErrorResponse.UNKNOWN_INTERACTION}.
     *
     * @param  modal 
     *         The Modal to send
     *
     * @throws IllegalArgumentException
     *         If the provided modal is null
     *        
     * @return ModalCallbackAction
     */
    @Nonnull
    @CheckReturnValue
    ModalCallbackAction replyModal(@Nonnull Modal modal);
}
